searchData={"items":[{"type":"module","title":"VelocyPack","doc":"An Elixir parser and generator for [VelocyPack](https://github.com/arangodb/velocypack/blob/master/VelocyPack.md) v1.\n\nThe implementation is heavily inspired by [Jason](https://github.com/michalmuskala/jason) and\nborrows some code (specifically the Codegen module).","ref":"VelocyPack.html"},{"type":"module","title":"Examples - VelocyPack","doc":"```elixir\niex> {:ok, vpack} = VelocyPack.encode(10.2312514)\n{:ok, <<27, 245, 78, 96, 149, 102, 118, 36, 64>>}\niex> VelocyPack.decode(vpack)\n{:ok, 10.2312514}\n\niex> vpack = VelocyPack.encode!(%{a: \"a\", b: %{bool: true, float: 10.2312514}})\n<<11, 37, 2, 65, 97, 65, 97, 65, 98, 11, 26, 2, 68, 98, 111, 111, 108, 26, 69, 102, 108, 111, 97, 116, 27, 245, 78, 96, 149, 102, 118, 36, 64, 3, 9, 3, 7>>\niex> VelocyPack.decode!(vpack)\n%{\"a\" => \"a\", \"b\" => %{\"bool\" => true, \"float\" => 10.2312514}}\n\niex> VelocyPack.decode(<<11>>)\n{:error, %VelocyPack.Error{message: \"unexpected sequence\", dump: nil}}\n\niex> VelocyPack.decode!(<<11>>)\n** (VelocyPack.Error) unexpected sequence\n\niex> VelocyPack.decode(<<11, 823891328731>>)\n{:error, %VelocyPack.Error{message: \"unexpected byte\", dump: \"<<0xDB>>\"}}\n\niex> VelocyPack.decode!(<<11, 823891328731>>)\n** (VelocyPack.Error) unexpected byte: <<0xDB>>\n```","ref":"VelocyPack.html#module-examples"},{"type":"function","title":"VelocyPack.decode/2","doc":"Parses the the first _VelocyPack_ value from a binary or iodata.\n\nThe options parameter is reserved for future use and not used at the moment.","ref":"VelocyPack.html#decode/2"},{"type":"function","title":"VelocyPack.decode!/2","doc":"Parses the the first _VelocyPack_ value from a binary or iodata.\n\nSame as `decode/2` except it will unwrap the tuple and raise\nin case of errors.","ref":"VelocyPack.html#decode!/2"},{"type":"function","title":"VelocyPack.encode/2","doc":"Generates a _VelocyPack_ value as a binary corresponding to `term`.\n\nThe generation is controlled by the `Velocy.Encoder` protocol,\nplease refer to the module to read more on how to define the protocol\nfor custom data types.\n\nThe options parameter is reserved for future use and not used at the moment.","ref":"VelocyPack.html#encode/2"},{"type":"function","title":"VelocyPack.encode!/2","doc":"Generates a _VelocyPack_ value as a binary corresponding to `term`.\n\nSame as `encode/2` except it will unwrap the tuple and raise\nin case of errors.","ref":"VelocyPack.html#encode!/2"},{"type":"type","title":"VelocyPack.vpack/0","doc":"","ref":"VelocyPack.html#t:vpack/0"},{"type":"module","title":"VelocyPack.Encode","doc":"","ref":"VelocyPack.Encode.html"},{"type":"function","title":"VelocyPack.Encode.atom/1","doc":"","ref":"VelocyPack.Encode.html#atom/1"},{"type":"function","title":"VelocyPack.Encode.build_index_table_1/3","doc":"","ref":"VelocyPack.Encode.html#build_index_table_1/3"},{"type":"function","title":"VelocyPack.Encode.build_index_table_2/3","doc":"","ref":"VelocyPack.Encode.html#build_index_table_2/3"},{"type":"function","title":"VelocyPack.Encode.build_index_table_4/3","doc":"","ref":"VelocyPack.Encode.html#build_index_table_4/3"},{"type":"function","title":"VelocyPack.Encode.build_index_table_8/3","doc":"","ref":"VelocyPack.Encode.html#build_index_table_8/3"},{"type":"function","title":"VelocyPack.Encode.encode/2","doc":"","ref":"VelocyPack.Encode.html#encode/2"},{"type":"function","title":"VelocyPack.Encode.float/1","doc":"","ref":"VelocyPack.Encode.html#float/1"},{"type":"function","title":"VelocyPack.Encode.integer/1","doc":"","ref":"VelocyPack.Encode.html#integer/1"},{"type":"function","title":"VelocyPack.Encode.list/2","doc":"","ref":"VelocyPack.Encode.html#list/2"},{"type":"function","title":"VelocyPack.Encode.map/2","doc":"","ref":"VelocyPack.Encode.html#map/2"},{"type":"function","title":"VelocyPack.Encode.string/1","doc":"","ref":"VelocyPack.Encode.html#string/1"},{"type":"protocol","title":"VelocyPack.Encoder","doc":"Protocol controlling how a value is encoded to _VelocyPack_.","ref":"VelocyPack.Encoder.html"},{"type":"function","title":"VelocyPack.Encoder.encode/2","doc":"","ref":"VelocyPack.Encoder.html#encode/2"},{"type":"type","title":"VelocyPack.Encoder.t/0","doc":"All the types that implement this protocol.","ref":"VelocyPack.Encoder.html#t:t/0"},{"type":"exception","title":"VelocyPack.Error","doc":"","ref":"VelocyPack.Error.html"},{"type":"extras","title":"VelocyPack","doc":"# VelocyPack\n\nAn Elixir parser and generator for [VelocyPack](https://github.com/arangodb/velocypack/blob/master/VelocyPack.md) v1.\n\nThe implementation is heavily inspired by [Jason](https://github.com/michalmuskala/jason) and\nborrows some code (specifically the Codegen module).","ref":"readme.html"},{"type":"extras","title":"Examples - VelocyPack","doc":"```elixir\niex> {:ok, vpack} = VelocyPack.encode(10.2312514)\n{:ok, <<27, 245, 78, 96, 149, 102, 118, 36, 64>>}\niex> VelocyPack.decode(vpack)\n{:ok, 10.2312514}\n\niex> vpack = VelocyPack.encode!(%{a: \"a\", b: %{bool: true, float: 10.2312514}})\n<<11, 37, 2, 65, 97, 65, 97, 65, 98, 11, 26, 2, 68, 98, 111, 111, 108, 26, 69, 102, 108, 111, 97, 116, 27, 245, 78, 96, 149, 102, 118, 36, 64, 3, 9, 3, 7>>\niex> VelocyPack.decode!(vpack)\n%{\"a\" => \"a\", \"b\" => %{\"bool\" => true, \"float\" => 10.2312514}}\n\niex> VelocyPack.decode(<<11>>)\n{:error, %VelocyPack.Error{message: \"unexpected sequence\", dump: nil}}\n\niex> VelocyPack.decode!(<<11>>)\n** (VelocyPack.Error) unexpected sequence\n\niex> VelocyPack.decode(<<11, 823891328731>>)\n{:error, %VelocyPack.Error{message: \"unexpected byte\", dump: \"<<0xDB>>\"}}\n\niex> VelocyPack.decode!(<<11, 823891328731>>)\n** (VelocyPack.Error) unexpected byte: <<0xDB>>\n```","ref":"readme.html#examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}